# 
# Licensed to the Apache Software Foundation (ASF) under one 
# or more contributor license agreements.  See the NOTICE file 
# distributed with this work for additional information 
# regarding copyright ownership.  The ASF licenses this file 
# to you under the Apache License, Version 2.0 (the 
# "License"); you may not use this file except in compliance 
# with the License.  You may obtain a copy of the License at 
# 
#   http://www.apache.org/licenses/LICENSE-2.0 
# 
# Unless required by applicable law or agreed to in writing, 
# software distributed under the License is distributed on an 
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY 
# KIND, either express or implied.  See the License for the 
# specific language governing permissions and limitations 
# under the License. 
# 

# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import message_pb2 as message__pb2
from . import metadata_service_pb2 as metadata__service__pb2


class MetadataServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getDatasetById = channel.unary_unary(
                '/ai_flow.MetadataService/getDatasetById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getDatasetByName = channel.unary_unary(
                '/ai_flow.MetadataService/getDatasetByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.listDatasets = channel.unary_unary(
                '/ai_flow.MetadataService/listDatasets',
                request_serializer=metadata__service__pb2.ListRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerDataset = channel.unary_unary(
                '/ai_flow.MetadataService/registerDataset',
                request_serializer=metadata__service__pb2.RegisterDatasetRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerDatasetWithCatalog = channel.unary_unary(
                '/ai_flow.MetadataService/registerDatasetWithCatalog',
                request_serializer=metadata__service__pb2.RegisterDatasetRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerDatasets = channel.unary_unary(
                '/ai_flow.MetadataService/registerDatasets',
                request_serializer=metadata__service__pb2.RegisterDatasetsRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.updateDataset = channel.unary_unary(
                '/ai_flow.MetadataService/updateDataset',
                request_serializer=metadata__service__pb2.UpdateDatasetRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteDatasetById = channel.unary_unary(
                '/ai_flow.MetadataService/deleteDatasetById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteDatasetByName = channel.unary_unary(
                '/ai_flow.MetadataService/deleteDatasetByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getModelRelationById = channel.unary_unary(
                '/ai_flow.MetadataService/getModelRelationById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getModelRelationByName = channel.unary_unary(
                '/ai_flow.MetadataService/getModelRelationByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.listModelRelation = channel.unary_unary(
                '/ai_flow.MetadataService/listModelRelation',
                request_serializer=metadata__service__pb2.ListRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerModelRelation = channel.unary_unary(
                '/ai_flow.MetadataService/registerModelRelation',
                request_serializer=metadata__service__pb2.RegisterModelRelationRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteModelRelationById = channel.unary_unary(
                '/ai_flow.MetadataService/deleteModelRelationById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteModelRelationByName = channel.unary_unary(
                '/ai_flow.MetadataService/deleteModelRelationByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getModelById = channel.unary_unary(
                '/ai_flow.MetadataService/getModelById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getModelByName = channel.unary_unary(
                '/ai_flow.MetadataService/getModelByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerModel = channel.unary_unary(
                '/ai_flow.MetadataService/registerModel',
                request_serializer=metadata__service__pb2.RegisterModelRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteModelById = channel.unary_unary(
                '/ai_flow.MetadataService/deleteModelById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteModelByName = channel.unary_unary(
                '/ai_flow.MetadataService/deleteModelByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getModelVersionRelationByVersion = channel.unary_unary(
                '/ai_flow.MetadataService/getModelVersionRelationByVersion',
                request_serializer=metadata__service__pb2.ModelVersionNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.listModelVersionRelation = channel.unary_unary(
                '/ai_flow.MetadataService/listModelVersionRelation',
                request_serializer=metadata__service__pb2.ListModelVersionRelationRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerModelVersionRelation = channel.unary_unary(
                '/ai_flow.MetadataService/registerModelVersionRelation',
                request_serializer=metadata__service__pb2.RegisterModelVersionRelationRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteModelVersionRelationByVersion = channel.unary_unary(
                '/ai_flow.MetadataService/deleteModelVersionRelationByVersion',
                request_serializer=metadata__service__pb2.ModelVersionNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getModelVersionByVersion = channel.unary_unary(
                '/ai_flow.MetadataService/getModelVersionByVersion',
                request_serializer=metadata__service__pb2.ModelVersionNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerModelVersion = channel.unary_unary(
                '/ai_flow.MetadataService/registerModelVersion',
                request_serializer=metadata__service__pb2.RegisterModelVersionRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteModelVersionByVersion = channel.unary_unary(
                '/ai_flow.MetadataService/deleteModelVersionByVersion',
                request_serializer=metadata__service__pb2.ModelVersionNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getDeployedModelVersion = channel.unary_unary(
                '/ai_flow.MetadataService/getDeployedModelVersion',
                request_serializer=metadata__service__pb2.ModelNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getLatestValidatedModelVersion = channel.unary_unary(
                '/ai_flow.MetadataService/getLatestValidatedModelVersion',
                request_serializer=metadata__service__pb2.ModelNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getLatestGeneratedModelVersion = channel.unary_unary(
                '/ai_flow.MetadataService/getLatestGeneratedModelVersion',
                request_serializer=metadata__service__pb2.ModelNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getProjectById = channel.unary_unary(
                '/ai_flow.MetadataService/getProjectById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getProjectByName = channel.unary_unary(
                '/ai_flow.MetadataService/getProjectByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerProject = channel.unary_unary(
                '/ai_flow.MetadataService/registerProject',
                request_serializer=metadata__service__pb2.RegisterProjectRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.updateProject = channel.unary_unary(
                '/ai_flow.MetadataService/updateProject',
                request_serializer=metadata__service__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.listProject = channel.unary_unary(
                '/ai_flow.MetadataService/listProject',
                request_serializer=metadata__service__pb2.ListRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteProjectById = channel.unary_unary(
                '/ai_flow.MetadataService/deleteProjectById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteProjectByName = channel.unary_unary(
                '/ai_flow.MetadataService/deleteProjectByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getArtifactById = channel.unary_unary(
                '/ai_flow.MetadataService/getArtifactById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getArtifactByName = channel.unary_unary(
                '/ai_flow.MetadataService/getArtifactByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.updateArtifact = channel.unary_unary(
                '/ai_flow.MetadataService/updateArtifact',
                request_serializer=metadata__service__pb2.UpdateArtifactRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerArtifact = channel.unary_unary(
                '/ai_flow.MetadataService/registerArtifact',
                request_serializer=metadata__service__pb2.RegisterArtifactRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.listArtifact = channel.unary_unary(
                '/ai_flow.MetadataService/listArtifact',
                request_serializer=metadata__service__pb2.ListRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteArtifactById = channel.unary_unary(
                '/ai_flow.MetadataService/deleteArtifactById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteArtifactByName = channel.unary_unary(
                '/ai_flow.MetadataService/deleteArtifactByName',
                request_serializer=metadata__service__pb2.NameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.registerWorkflow = channel.unary_unary(
                '/ai_flow.MetadataService/registerWorkflow',
                request_serializer=metadata__service__pb2.RegisterWorkflowRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.updateWorkflow = channel.unary_unary(
                '/ai_flow.MetadataService/updateWorkflow',
                request_serializer=metadata__service__pb2.UpdateWorkflowRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getWorkflowById = channel.unary_unary(
                '/ai_flow.MetadataService/getWorkflowById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.getWorkflowByName = channel.unary_unary(
                '/ai_flow.MetadataService/getWorkflowByName',
                request_serializer=metadata__service__pb2.WorkflowNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteWorkflowById = channel.unary_unary(
                '/ai_flow.MetadataService/deleteWorkflowById',
                request_serializer=metadata__service__pb2.IdRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.deleteWorkflowByName = channel.unary_unary(
                '/ai_flow.MetadataService/deleteWorkflowByName',
                request_serializer=metadata__service__pb2.WorkflowNameRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )
        self.listWorkflows = channel.unary_unary(
                '/ai_flow.MetadataService/listWorkflows',
                request_serializer=metadata__service__pb2.ListWorkflowsRequest.SerializeToString,
                response_deserializer=message__pb2.Response.FromString,
                )


class MetadataServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def getDatasetById(self, request, context):
        """dataset api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDatasetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listDatasets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerDatasetWithCatalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerDatasets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateDataset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteDatasetById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteDatasetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getModelRelationById(self, request, context):
        """model relation api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getModelRelationByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listModelRelation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerModelRelation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteModelRelationById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteModelRelationByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getModelById(self, request, context):
        """model api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getModelByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteModelById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteModelByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getModelVersionRelationByVersion(self, request, context):
        """model version relation api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listModelVersionRelation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerModelVersionRelation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteModelVersionRelationByVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getModelVersionByVersion(self, request, context):
        """model version api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerModelVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteModelVersionByVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDeployedModelVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getLatestValidatedModelVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getLatestGeneratedModelVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getProjectById(self, request, context):
        """project api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getProjectByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteProjectById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteProjectByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getArtifactById(self, request, context):
        """artifact api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getArtifactByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteArtifactById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteArtifactByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getWorkflowById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getWorkflowByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteWorkflowById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteWorkflowByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listWorkflows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetadataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getDatasetById': grpc.unary_unary_rpc_method_handler(
                    servicer.getDatasetById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getDatasetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.getDatasetByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'listDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.listDatasets,
                    request_deserializer=metadata__service__pb2.ListRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.registerDataset,
                    request_deserializer=metadata__service__pb2.RegisterDatasetRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerDatasetWithCatalog': grpc.unary_unary_rpc_method_handler(
                    servicer.registerDatasetWithCatalog,
                    request_deserializer=metadata__service__pb2.RegisterDatasetRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerDatasets': grpc.unary_unary_rpc_method_handler(
                    servicer.registerDatasets,
                    request_deserializer=metadata__service__pb2.RegisterDatasetsRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'updateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.updateDataset,
                    request_deserializer=metadata__service__pb2.UpdateDatasetRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteDatasetById': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteDatasetById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteDatasetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteDatasetByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getModelRelationById': grpc.unary_unary_rpc_method_handler(
                    servicer.getModelRelationById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getModelRelationByName': grpc.unary_unary_rpc_method_handler(
                    servicer.getModelRelationByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'listModelRelation': grpc.unary_unary_rpc_method_handler(
                    servicer.listModelRelation,
                    request_deserializer=metadata__service__pb2.ListRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerModelRelation': grpc.unary_unary_rpc_method_handler(
                    servicer.registerModelRelation,
                    request_deserializer=metadata__service__pb2.RegisterModelRelationRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteModelRelationById': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteModelRelationById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteModelRelationByName': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteModelRelationByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getModelById': grpc.unary_unary_rpc_method_handler(
                    servicer.getModelById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getModelByName': grpc.unary_unary_rpc_method_handler(
                    servicer.getModelByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerModel': grpc.unary_unary_rpc_method_handler(
                    servicer.registerModel,
                    request_deserializer=metadata__service__pb2.RegisterModelRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteModelById': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteModelById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteModelByName': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteModelByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getModelVersionRelationByVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.getModelVersionRelationByVersion,
                    request_deserializer=metadata__service__pb2.ModelVersionNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'listModelVersionRelation': grpc.unary_unary_rpc_method_handler(
                    servicer.listModelVersionRelation,
                    request_deserializer=metadata__service__pb2.ListModelVersionRelationRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerModelVersionRelation': grpc.unary_unary_rpc_method_handler(
                    servicer.registerModelVersionRelation,
                    request_deserializer=metadata__service__pb2.RegisterModelVersionRelationRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteModelVersionRelationByVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteModelVersionRelationByVersion,
                    request_deserializer=metadata__service__pb2.ModelVersionNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getModelVersionByVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.getModelVersionByVersion,
                    request_deserializer=metadata__service__pb2.ModelVersionNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.registerModelVersion,
                    request_deserializer=metadata__service__pb2.RegisterModelVersionRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteModelVersionByVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteModelVersionByVersion,
                    request_deserializer=metadata__service__pb2.ModelVersionNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getDeployedModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.getDeployedModelVersion,
                    request_deserializer=metadata__service__pb2.ModelNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getLatestValidatedModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.getLatestValidatedModelVersion,
                    request_deserializer=metadata__service__pb2.ModelNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getLatestGeneratedModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.getLatestGeneratedModelVersion,
                    request_deserializer=metadata__service__pb2.ModelNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getProjectById': grpc.unary_unary_rpc_method_handler(
                    servicer.getProjectById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getProjectByName': grpc.unary_unary_rpc_method_handler(
                    servicer.getProjectByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerProject': grpc.unary_unary_rpc_method_handler(
                    servicer.registerProject,
                    request_deserializer=metadata__service__pb2.RegisterProjectRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'updateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.updateProject,
                    request_deserializer=metadata__service__pb2.UpdateProjectRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'listProject': grpc.unary_unary_rpc_method_handler(
                    servicer.listProject,
                    request_deserializer=metadata__service__pb2.ListRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteProjectById': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteProjectById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteProjectByName': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteProjectByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getArtifactById': grpc.unary_unary_rpc_method_handler(
                    servicer.getArtifactById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getArtifactByName': grpc.unary_unary_rpc_method_handler(
                    servicer.getArtifactByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'updateArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.updateArtifact,
                    request_deserializer=metadata__service__pb2.UpdateArtifactRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.registerArtifact,
                    request_deserializer=metadata__service__pb2.RegisterArtifactRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'listArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.listArtifact,
                    request_deserializer=metadata__service__pb2.ListRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteArtifactById': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteArtifactById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteArtifactByName': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteArtifactByName,
                    request_deserializer=metadata__service__pb2.NameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'registerWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.registerWorkflow,
                    request_deserializer=metadata__service__pb2.RegisterWorkflowRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'updateWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.updateWorkflow,
                    request_deserializer=metadata__service__pb2.UpdateWorkflowRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getWorkflowById': grpc.unary_unary_rpc_method_handler(
                    servicer.getWorkflowById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'getWorkflowByName': grpc.unary_unary_rpc_method_handler(
                    servicer.getWorkflowByName,
                    request_deserializer=metadata__service__pb2.WorkflowNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteWorkflowById': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteWorkflowById,
                    request_deserializer=metadata__service__pb2.IdRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'deleteWorkflowByName': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteWorkflowByName,
                    request_deserializer=metadata__service__pb2.WorkflowNameRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
            'listWorkflows': grpc.unary_unary_rpc_method_handler(
                    servicer.listWorkflows,
                    request_deserializer=metadata__service__pb2.ListWorkflowsRequest.FromString,
                    response_serializer=message__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai_flow.MetadataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MetadataService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def getDatasetById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getDatasetById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDatasetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getDatasetByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/listDatasets',
            metadata__service__pb2.ListRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerDataset',
            metadata__service__pb2.RegisterDatasetRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerDatasetWithCatalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerDatasetWithCatalog',
            metadata__service__pb2.RegisterDatasetRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerDatasets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerDatasets',
            metadata__service__pb2.RegisterDatasetsRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/updateDataset',
            metadata__service__pb2.UpdateDatasetRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteDatasetById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteDatasetById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteDatasetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteDatasetByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getModelRelationById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getModelRelationById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getModelRelationByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getModelRelationByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listModelRelation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/listModelRelation',
            metadata__service__pb2.ListRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerModelRelation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerModelRelation',
            metadata__service__pb2.RegisterModelRelationRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteModelRelationById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteModelRelationById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteModelRelationByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteModelRelationByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getModelById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getModelById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getModelByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getModelByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerModel',
            metadata__service__pb2.RegisterModelRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteModelById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteModelById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteModelByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteModelByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getModelVersionRelationByVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getModelVersionRelationByVersion',
            metadata__service__pb2.ModelVersionNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listModelVersionRelation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/listModelVersionRelation',
            metadata__service__pb2.ListModelVersionRelationRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerModelVersionRelation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerModelVersionRelation',
            metadata__service__pb2.RegisterModelVersionRelationRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteModelVersionRelationByVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteModelVersionRelationByVersion',
            metadata__service__pb2.ModelVersionNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getModelVersionByVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getModelVersionByVersion',
            metadata__service__pb2.ModelVersionNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerModelVersion',
            metadata__service__pb2.RegisterModelVersionRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteModelVersionByVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteModelVersionByVersion',
            metadata__service__pb2.ModelVersionNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDeployedModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getDeployedModelVersion',
            metadata__service__pb2.ModelNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getLatestValidatedModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getLatestValidatedModelVersion',
            metadata__service__pb2.ModelNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getLatestGeneratedModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getLatestGeneratedModelVersion',
            metadata__service__pb2.ModelNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getProjectById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getProjectById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getProjectByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getProjectByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerProject',
            metadata__service__pb2.RegisterProjectRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/updateProject',
            metadata__service__pb2.UpdateProjectRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/listProject',
            metadata__service__pb2.ListRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteProjectById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteProjectById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteProjectByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteProjectByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getArtifactById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getArtifactById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getArtifactByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getArtifactByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/updateArtifact',
            metadata__service__pb2.UpdateArtifactRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerArtifact',
            metadata__service__pb2.RegisterArtifactRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/listArtifact',
            metadata__service__pb2.ListRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteArtifactById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteArtifactById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteArtifactByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteArtifactByName',
            metadata__service__pb2.NameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/registerWorkflow',
            metadata__service__pb2.RegisterWorkflowRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/updateWorkflow',
            metadata__service__pb2.UpdateWorkflowRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getWorkflowById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getWorkflowById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getWorkflowByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/getWorkflowByName',
            metadata__service__pb2.WorkflowNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteWorkflowById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteWorkflowById',
            metadata__service__pb2.IdRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteWorkflowByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/deleteWorkflowByName',
            metadata__service__pb2.WorkflowNameRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listWorkflows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai_flow.MetadataService/listWorkflows',
            metadata__service__pb2.ListWorkflowsRequest.SerializeToString,
            message__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.


def _strip_unsafe_kubernetes_special_chars(string: str) -> str:
    """
    Kubernetes only supports lowercase alphanumeric characters, "-" and "." in
    the pod name.
    However, there are special rules about how "-" and "." can be used so let's
    only keep
    alphanumeric chars  see here for detail:
    https://kubernetes.io/docs/concepts/overview/working-with-objects/names/

    :param string: The requested Pod name
    :return: Pod name stripped of any unsafe characters
    """
    return ''.join(ch.lower() for ch in list(string) if ch.isalnum())


def create_pod_id(dag_id: str, task_id: str) -> str:
    """
    Generates the kubernetes safe pod_id. Note that this is
    NOT the full ID that will be launched to k8s. We will add a uuid
    to ensure uniqueness.

    :param dag_id: DAG ID
    :param task_id: Task ID
    :return: The non-unique pod_id for this task/DAG pairing
    """
    safe_dag_id = _strip_unsafe_kubernetes_special_chars(dag_id)
    safe_task_id = _strip_unsafe_kubernetes_special_chars(task_id)
    return safe_dag_id + safe_task_id



#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#
from ai_flow.endpoint.server.util import catch_exception
from ai_flow.metric.utils import proto_to_metric_meta, _warp_metric_meta_response, _warp_list_metric_metas_response, \
    proto_to_metric_summary, _warp_metric_summary_response, _warp_list_metric_summaries_response
from ai_flow.protobuf.message_pb2 import Response, ReturnCode
from ai_flow.protobuf.metric_service_pb2_grpc import MetricServiceServicer
from ai_flow.store.sqlalchemy_store import SqlAlchemyStore


class MetricService(MetricServiceServicer):

    def __init__(self, db_uri):
        self.db_uri = db_uri
        self.store = SqlAlchemyStore(self.db_uri)

    @catch_exception
    def registerMetricMeta(self, request, context):
        metric_meta_proto = request.metric_meta
        metric_meta = proto_to_metric_meta(metric_meta_proto)
        res_metric_meta = self.store.register_metric_meta(metric_meta.metric_name,
                                                          metric_meta.metric_type,
                                                          metric_meta.project_name,
                                                          metric_meta.metric_desc,
                                                          metric_meta.dataset_name,
                                                          metric_meta.model_name,
                                                          metric_meta.job_name,
                                                          metric_meta.start_time,
                                                          metric_meta.end_time,
                                                          metric_meta.uri,
                                                          metric_meta.tags,
                                                          metric_meta.properties)
        return _warp_metric_meta_response(res_metric_meta)

    @catch_exception
    def updateMetricMeta(self, request, context):
        metric_meta_proto = request.metric_meta
        metric_meta = proto_to_metric_meta(metric_meta_proto)
        res_metric_meta = self.store.update_metric_meta(metric_meta.metric_name,
                                                        metric_meta.metric_desc,
                                                        metric_meta.project_name,
                                                        metric_meta.dataset_name,
                                                        metric_meta.model_name,
                                                        metric_meta.job_name,
                                                        metric_meta.start_time,
                                                        metric_meta.end_time,
                                                        metric_meta.uri,
                                                        metric_meta.tags,
                                                        metric_meta.properties)
        return _warp_metric_meta_response(res_metric_meta)

    @catch_exception
    def deleteMetricMeta(self, request, context):
        metric_name = request.metric_name
        try:
            self.store.delete_metric_meta(metric_name)
            return Response(return_code=str(ReturnCode.SUCCESS), return_msg='', data='')
        except Exception as e:
            return Response(return_code=str(ReturnCode.INTERNAL_ERROR), return_msg=str(e), data='')

    @catch_exception
    def getMetricMeta(self, request, context):
        metric_name = request.metric_name
        res_metric_meta = self.store.get_metric_meta(metric_name)
        return _warp_metric_meta_response(res_metric_meta)

    @catch_exception
    def listDatasetMetricMetas(self, request, context):
        dataset_name = request.dataset_name
        project_name = request.project_name.value if request.HasField('project_name') else None
        metric_metas = self.store.list_dataset_metric_metas(dataset_name=dataset_name, project_name=project_name)
        return _warp_list_metric_metas_response(metric_metas)

    @catch_exception
    def listModelMetricMetas(self, request, context):
        model_name = request.model_name
        project_name = request.project_name.value if request.HasField('project_name') else None
        metric_metas = self.store.list_model_metric_metas(model_name=model_name, project_name=project_name)
        return _warp_list_metric_metas_response(metric_metas)

    @catch_exception
    def registerMetricSummary(self, request, context):
        metric_summary_proto = request.metric_summary
        metric_summary = proto_to_metric_summary(metric_summary_proto)
        res_metric_summary = self.store.register_metric_summary(metric_summary.metric_name,
                                                                metric_summary.metric_key,
                                                                metric_summary.metric_value,
                                                                metric_summary.metric_timestamp,
                                                                metric_summary.model_version,
                                                                metric_summary.job_execution_id)
        return _warp_metric_summary_response(res_metric_summary)

    @catch_exception
    def updateMetricSummary(self, request, context):
        metric_summary_proto = request.metric_summary
        metric_summary = proto_to_metric_summary(metric_summary_proto)
        res_metric_summary = self.store.update_metric_summary(metric_summary.uuid,
                                                              metric_summary.metric_name,
                                                              metric_summary.metric_key,
                                                              metric_summary.metric_value,
                                                              metric_summary.metric_timestamp,
                                                              metric_summary.model_version,
                                                              metric_summary.job_execution_id)
        return _warp_metric_summary_response(res_metric_summary)

    @catch_exception
    def deleteMetricSummary(self, request, context):
        uuid = request.uuid
        try:
            self.store.delete_metric_summary(uuid)
            return Response(return_code=str(ReturnCode.SUCCESS), return_msg='', data='')
        except Exception as e:
            return Response(return_code=str(ReturnCode.INTERNAL_ERROR), return_msg=str(e), data='')

    @catch_exception
    def getMetricSummary(self, request, context):
        uuid = request.uuid
        metric_summary = self.store.get_metric_summary(uuid)
        return _warp_metric_summary_response(metric_summary)

    @catch_exception
    def listMetricSummaries(self, request, context):
        metric_name = request.metric_name.value if request.HasField('metric_name') else None
        metric_key = request.metric_key.value if request.HasField('metric_key') else None
        model_version = request.model_version.value if request.HasField('model_version') else None
        start_time = request.start_time.value if request.HasField('start_time') else None
        end_time = request.end_time.value if request.HasField('end_time') else None
        metric_summaries = self.store.list_metric_summaries(metric_name, metric_key, model_version, start_time,
                                                            end_time)
        return _warp_list_metric_summaries_response(metric_summaries)



#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

import json
import logging
import pickle
from json import JSONDecodeError
from typing import Any, Iterable, Optional, Union

import pendulum
from sqlalchemy import Column, LargeBinary, String, and_
from sqlalchemy.orm import Query, Session, reconstructor

from airflow.configuration import conf
from airflow.models.base import COLLATION_ARGS, ID_LEN, Base
from airflow.utils import timezone
from airflow.utils.helpers import is_container
from airflow.utils.log.logging_mixin import LoggingMixin
from airflow.utils.session import provide_session
from airflow.utils.sqlalchemy import UtcDateTime

log = logging.getLogger(__name__)

# MAX XCOM Size is 48KB
# https://github.com/apache/airflow/pull/1618#discussion_r68249677
MAX_XCOM_SIZE = 49344
XCOM_RETURN_KEY = 'return_value'


class BaseXCom(Base, LoggingMixin):
    """Base class for XCom objects."""

    __tablename__ = "xcom"

    key = Column(String(512, **COLLATION_ARGS), primary_key=True)
    value = Column(LargeBinary)
    timestamp = Column(UtcDateTime, default=timezone.utcnow, nullable=False)
    execution_date = Column(UtcDateTime, primary_key=True)

    # source information
    task_id = Column(String(ID_LEN, **COLLATION_ARGS), primary_key=True)
    dag_id = Column(String(ID_LEN, **COLLATION_ARGS), primary_key=True)

    @reconstructor
    def init_on_load(self):
        """
        Called by the ORM after the instance has been loaded from the DB or otherwise reconstituted
        i.e automatically deserialize Xcom value when loading from DB.
        """
        try:
            self.value = self.orm_deserialize_value()
        except (UnicodeEncodeError, ValueError):
            # For backward-compatibility.
            # Preventing errors in webserver
            # due to XComs mixed with pickled and unpickled.
            self.value = pickle.loads(self.value)

    def __repr__(self):
        return '<XCom "{key}" ({task_id} @ {execution_date})>'.format(
            key=self.key, task_id=self.task_id, execution_date=self.execution_date
        )

    @classmethod
    @provide_session
    def set(cls, key, value, execution_date, task_id, dag_id, session=None):
        """
        Store an XCom value.

        :return: None
        """
        session.expunge_all()

        value = XCom.serialize_value(value)

        # remove any duplicate XComs
        session.query(cls).filter(
            cls.key == key, cls.execution_date == execution_date, cls.task_id == task_id, cls.dag_id == dag_id
        ).delete()

        session.commit()

        # insert new XCom
        session.add(XCom(key=key, value=value, execution_date=execution_date, task_id=task_id, dag_id=dag_id))

        session.commit()

    @classmethod
    @provide_session
    def get_one(
        cls,
        execution_date: pendulum.DateTime,
        key: Optional[str] = None,
        task_id: Optional[Union[str, Iterable[str]]] = None,
        dag_id: Optional[Union[str, Iterable[str]]] = None,
        include_prior_dates: bool = False,
        session: Session = None,
    ) -> Optional[Any]:
        """
        Retrieve an XCom value, optionally meeting certain criteria. Returns None
        of there are no results.

        :param execution_date: Execution date for the task
        :type execution_date: pendulum.datetime
        :param key: A key for the XCom. If provided, only XComs with matching
            keys will be returned. To remove the filter, pass key=None.
        :type key: str
        :param task_id: Only XComs from task with matching id will be
            pulled. Can pass None to remove the filter.
        :type task_id: str
        :param dag_id: If provided, only pulls XCom from this DAG.
            If None (default), the DAG of the calling task is used.
        :type dag_id: str
        :param include_prior_dates: If False, only XCom from the current
            execution_date are returned. If True, XCom from previous dates
            are returned as well.
        :type include_prior_dates: bool
        :param session: database session
        :type session: sqlalchemy.orm.session.Session
        """
        result = cls.get_many(
            execution_date=execution_date,
            key=key,
            task_ids=task_id,
            dag_ids=dag_id,
            include_prior_dates=include_prior_dates,
            session=session,
        ).first()
        if result:
            return result.value
        return None

    @classmethod
    @provide_session
    def get_many(
        cls,
        execution_date: pendulum.DateTime,
        key: Optional[str] = None,
        task_ids: Optional[Union[str, Iterable[str]]] = None,
        dag_ids: Optional[Union[str, Iterable[str]]] = None,
        include_prior_dates: bool = False,
        limit: Optional[int] = None,
        session: Session = None,
    ) -> Query:
        """
        Composes a query to get one or more values from the xcom table.

        :param execution_date: Execution date for the task
        :type execution_date: pendulum.datetime
        :param key: A key for the XCom. If provided, only XComs with matching
            keys will be returned. To remove the filter, pass key=None.
        :type key: str
        :param task_ids: Only XComs from tasks with matching ids will be
            pulled. Can pass None to remove the filter.
        :type task_ids: str or iterable of strings (representing task_ids)
        :param dag_ids: If provided, only pulls XComs from this DAG.
            If None (default), the DAG of the calling task is used.
        :type dag_ids: str
        :param include_prior_dates: If False, only XComs from the current
            execution_date are returned. If True, XComs from previous dates
            are returned as well.
        :type include_prior_dates: bool
        :param limit: If required, limit the number of returned objects.
            XCom objects can be quite big and you might want to limit the
            number of rows.
        :type limit: int
        :param session: database session
        :type session: sqlalchemy.orm.session.Session
        """
        filters = []

        if key:
            filters.append(cls.key == key)

        if task_ids:
            if is_container(task_ids):
                filters.append(cls.task_id.in_(task_ids))
            else:
                filters.append(cls.task_id == task_ids)

        if dag_ids:
            if is_container(dag_ids):
                filters.append(cls.dag_id.in_(dag_ids))
            else:
                filters.append(cls.dag_id == dag_ids)

        if include_prior_dates:
            filters.append(cls.execution_date <= execution_date)
        else:
            filters.append(cls.execution_date == execution_date)

        query = (
            session.query(cls)
            .filter(and_(*filters))
            .order_by(cls.execution_date.desc(), cls.timestamp.desc())
        )

        if limit:
            return query.limit(limit)
        else:
            return query

    @classmethod
    @provide_session
    def delete(cls, xcoms, session=None):
        """Delete Xcom"""
        if isinstance(xcoms, XCom):
            xcoms = [xcoms]
        for xcom in xcoms:
            if not isinstance(xcom, XCom):
                raise TypeError(f'Expected XCom; received {xcom.__class__.__name__}')
            session.delete(xcom)
        session.commit()

    @staticmethod
    def serialize_value(value: Any):
        """Serialize Xcom value to str or pickled object"""
        if conf.getboolean('core', 'enable_xcom_pickling'):
            return pickle.dumps(value)
        try:
            return json.dumps(value).encode('UTF-8')
        except (ValueError, TypeError):
            log.error(
                "Could not serialize the XCom value into JSON. "
                "If you are using pickles instead of JSON "
                "for XCom, then you need to enable pickle "
                "support for XCom in your airflow config."
            )
            raise

    @staticmethod
    def deserialize_value(result: "XCom") -> Any:
        """Deserialize XCom value from str or pickle object"""
        enable_pickling = conf.getboolean('core', 'enable_xcom_pickling')
        if enable_pickling:
            try:
                return pickle.loads(result.value)
            except pickle.UnpicklingError:
                return json.loads(result.value.decode('UTF-8'))
        try:
            return json.loads(result.value.decode('UTF-8'))
        except JSONDecodeError:
            log.error(
                "Could not deserialize the XCom value from JSON. "
                "If you are using pickles instead of JSON "
                "for XCom, then you need to enable pickle "
                "support for XCom in your airflow config."
            )
            raise

    def orm_deserialize_value(self) -> Any:
        """
        Deserialize method which is used to reconstruct ORM XCom object.

        This method should be overridden in custom XCom backends to avoid
        unnecessary request or other resource consuming operations when
        creating XCom orm model. This is used when viewing XCom listing
        in the webserver, for example.
        """
        return BaseXCom.deserialize_value(self)


def resolve_xcom_backend():
    """Resolves custom XCom class"""
    clazz = conf.getimport("core", "xcom_backend", fallback=f"airflow.models.xcom.{BaseXCom.__name__}")
    if clazz:
        if not issubclass(clazz, BaseXCom):
            raise TypeError(
                f"Your custom XCom class `{clazz.__name__}` is not a subclass of `{BaseXCom.__name__}`."
            )
        return clazz
    return BaseXCom


XCom = resolve_xcom_backend()



#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scheduling_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import message_pb2 as message__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='scheduling_service.proto',
  package='ai_flow',
  syntax='proto3',
  serialized_options=b'\n\020com.aiflow.protoZ\010/ai_flow\210\001\001\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18scheduling_service.proto\x12\x07\x61i_flow\x1a\rmessage.proto\x1a\x1cgoogle/api/annotations.proto\"\xc1\x01\n\x17ScheduleWorkflowRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x15\n\rworkflow_name\x18\x02 \x01(\t\x12\x38\n\x04\x61rgs\x18\x03 \x03(\x0b\x32*.ai_flow.ScheduleWorkflowRequest.ArgsEntry\x12\x15\n\rworkflow_json\x18\x04 \x01(\t\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x01\n\x18WorkflowExecutionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\x12\x15\n\rworkflow_name\x18\x03 \x01(\t\x12\x39\n\x04\x61rgs\x18\x04 \x03(\x0b\x32+.ai_flow.WorkflowExecutionRequest.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x12ScheduleJobRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x10\n\x08job_name\x18\x02 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x03 \x01(\t\"f\n\x14WorkflowInfoResponse\x12$\n\x06result\x18\x01 \x01(\x0b\x32\x14.ai_flow.ResultProto\x12(\n\x08workflow\x18\x02 \x01(\x0b\x32\x16.ai_flow.WorkflowProto\"o\n\x18ListWorkflowInfoResponse\x12$\n\x06result\x18\x01 \x01(\x0b\x32\x14.ai_flow.ResultProto\x12-\n\rworkflow_list\x18\x02 \x03(\x0b\x32\x16.ai_flow.WorkflowProto\"~\n\x19WorkflowExecutionResponse\x12$\n\x06result\x18\x01 \x01(\x0b\x32\x14.ai_flow.ResultProto\x12;\n\x12workflow_execution\x18\x02 \x01(\x0b\x32\x1f.ai_flow.WorkflowExecutionProto\"\x87\x01\n\x1dListWorkflowExecutionResponse\x12$\n\x06result\x18\x01 \x01(\x0b\x32\x14.ai_flow.ResultProto\x12@\n\x17workflow_execution_list\x18\x02 \x03(\x0b\x32\x1f.ai_flow.WorkflowExecutionProto\"W\n\x0fJobInfoResponse\x12$\n\x06result\x18\x01 \x01(\x0b\x32\x14.ai_flow.ResultProto\x12\x1e\n\x03job\x18\x02 \x01(\x0b\x32\x11.ai_flow.JobProto\"`\n\x13ListJobInfoResponse\x12$\n\x06result\x18\x01 \x01(\x0b\x32\x14.ai_flow.ResultProto\x12#\n\x08job_list\x18\x02 \x03(\x0b\x32\x11.ai_flow.JobProto2\xcb\x10\n\x11SchedulingService\x12\x80\x01\n\x0esubmitWorkflow\x12 .ai_flow.ScheduleWorkflowRequest\x1a\x1d.ai_flow.WorkflowInfoResponse\"-\x82\xd3\xe4\x93\x02\'\"\"/aiflow/scheduling/workflow/submit:\x01*\x12\x80\x01\n\x0e\x64\x65leteWorkflow\x12 .ai_flow.ScheduleWorkflowRequest\x1a\x1d.ai_flow.WorkflowInfoResponse\"-\x82\xd3\xe4\x93\x02\'\"\"/aiflow/scheduling/workflow/delete:\x01*\x12\x88\x01\n\x17pauseWorkflowScheduling\x12 .ai_flow.ScheduleWorkflowRequest\x1a\x1d.ai_flow.WorkflowInfoResponse\",\x82\xd3\xe4\x93\x02&\"!/aiflow/scheduling/workflow/pause:\x01*\x12\x8a\x01\n\x18resumeWorkflowScheduling\x12 .ai_flow.ScheduleWorkflowRequest\x1a\x1d.ai_flow.WorkflowInfoResponse\"-\x82\xd3\xe4\x93\x02\'\"\"/aiflow/scheduling/workflow/resume:\x01*\x12w\n\x0bgetWorkflow\x12 .ai_flow.ScheduleWorkflowRequest\x1a\x1d.ai_flow.WorkflowInfoResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/aiflow/scheduling/workflow/get\x12~\n\rlistWorkflows\x12 .ai_flow.ScheduleWorkflowRequest\x1a!.ai_flow.ListWorkflowInfoResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /aiflow/scheduling/workflow/list\x12\x9e\x01\n\x19startNewWorkflowExecution\x12!.ai_flow.WorkflowExecutionRequest\x1a\".ai_flow.WorkflowExecutionResponse\":\x82\xd3\xe4\x93\x02\x34\"//aiflow/scheduling/workflow_execution/start_new:\x01*\x12\xa1\x01\n\x19killAllWorkflowExecutions\x12!.ai_flow.WorkflowExecutionRequest\x1a&.ai_flow.ListWorkflowExecutionResponse\"9\x82\xd3\xe4\x93\x02\x33\"./aiflow/scheduling/workflow_execution/kill_all:\x01*\x12\x95\x01\n\x15killWorkflowExecution\x12!.ai_flow.WorkflowExecutionRequest\x1a\".ai_flow.WorkflowExecutionResponse\"5\x82\xd3\xe4\x93\x02/\"*/aiflow/scheduling/workflow_execution/kill:\x01*\x12\x90\x01\n\x14getWorkflowExecution\x12!.ai_flow.WorkflowExecutionRequest\x1a\".ai_flow.WorkflowExecutionResponse\"1\x82\xd3\xe4\x93\x02+\x12)/aiflow/scheduling/workflow_execution/get\x12\x97\x01\n\x16listWorkflowExecutions\x12!.ai_flow.WorkflowExecutionRequest\x1a&.ai_flow.ListWorkflowExecutionResponse\"2\x82\xd3\xe4\x93\x02,\x12*/aiflow/scheduling/workflow_execution/list\x12j\n\x08startJob\x12\x1b.ai_flow.ScheduleJobRequest\x1a\x18.ai_flow.JobInfoResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/aiflow/scheduling/job/start:\x01*\x12h\n\x07stopJob\x12\x1b.ai_flow.ScheduleJobRequest\x1a\x18.ai_flow.JobInfoResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/aiflow/scheduling/job/stop:\x01*\x12n\n\nrestartJob\x12\x1b.ai_flow.ScheduleJobRequest\x1a\x18.ai_flow.JobInfoResponse\")\x82\xd3\xe4\x93\x02#\"\x1e/aiflow/scheduling/job/restart:\x01*\x12\x63\n\x06getJob\x12\x1b.ai_flow.ScheduleJobRequest\x1a\x18.ai_flow.JobInfoResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/aiflow/scheduling/job/get\x12j\n\x08listJobs\x12\x1b.ai_flow.ScheduleJobRequest\x1a\x1c.ai_flow.ListJobInfoResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/aiflow/scheduling/job/listB\"\n\x10\x63om.aiflow.protoZ\x08/ai_flow\x88\x01\x01\x90\x01\x01\x62\x06proto3'
  ,
  dependencies=[message__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_SCHEDULEWORKFLOWREQUEST_ARGSENTRY = _descriptor.Descriptor(
  name='ArgsEntry',
  full_name='ai_flow.ScheduleWorkflowRequest.ArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ai_flow.ScheduleWorkflowRequest.ArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai_flow.ScheduleWorkflowRequest.ArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=276,
)

_SCHEDULEWORKFLOWREQUEST = _descriptor.Descriptor(
  name='ScheduleWorkflowRequest',
  full_name='ai_flow.ScheduleWorkflowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='ai_flow.ScheduleWorkflowRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_name', full_name='ai_flow.ScheduleWorkflowRequest.workflow_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='ai_flow.ScheduleWorkflowRequest.args', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_json', full_name='ai_flow.ScheduleWorkflowRequest.workflow_json', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCHEDULEWORKFLOWREQUEST_ARGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=276,
)


_WORKFLOWEXECUTIONREQUEST_ARGSENTRY = _descriptor.Descriptor(
  name='ArgsEntry',
  full_name='ai_flow.WorkflowExecutionRequest.ArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ai_flow.WorkflowExecutionRequest.ArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai_flow.WorkflowExecutionRequest.ArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=276,
)

_WORKFLOWEXECUTIONREQUEST = _descriptor.Descriptor(
  name='WorkflowExecutionRequest',
  full_name='ai_flow.WorkflowExecutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='ai_flow.WorkflowExecutionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='ai_flow.WorkflowExecutionRequest.execution_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_name', full_name='ai_flow.WorkflowExecutionRequest.workflow_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='ai_flow.WorkflowExecutionRequest.args', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WORKFLOWEXECUTIONREQUEST_ARGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=473,
)


_SCHEDULEJOBREQUEST = _descriptor.Descriptor(
  name='ScheduleJobRequest',
  full_name='ai_flow.ScheduleJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='ai_flow.ScheduleJobRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_name', full_name='ai_flow.ScheduleJobRequest.job_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='ai_flow.ScheduleJobRequest.execution_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=554,
)


_WORKFLOWINFORESPONSE = _descriptor.Descriptor(
  name='WorkflowInfoResponse',
  full_name='ai_flow.WorkflowInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai_flow.WorkflowInfoResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='ai_flow.WorkflowInfoResponse.workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=658,
)


_LISTWORKFLOWINFORESPONSE = _descriptor.Descriptor(
  name='ListWorkflowInfoResponse',
  full_name='ai_flow.ListWorkflowInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai_flow.ListWorkflowInfoResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_list', full_name='ai_flow.ListWorkflowInfoResponse.workflow_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=771,
)


_WORKFLOWEXECUTIONRESPONSE = _descriptor.Descriptor(
  name='WorkflowExecutionResponse',
  full_name='ai_flow.WorkflowExecutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai_flow.WorkflowExecutionResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_execution', full_name='ai_flow.WorkflowExecutionResponse.workflow_execution', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=899,
)


_LISTWORKFLOWEXECUTIONRESPONSE = _descriptor.Descriptor(
  name='ListWorkflowExecutionResponse',
  full_name='ai_flow.ListWorkflowExecutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai_flow.ListWorkflowExecutionResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_execution_list', full_name='ai_flow.ListWorkflowExecutionResponse.workflow_execution_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=1037,
)


_JOBINFORESPONSE = _descriptor.Descriptor(
  name='JobInfoResponse',
  full_name='ai_flow.JobInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai_flow.JobInfoResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job', full_name='ai_flow.JobInfoResponse.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1126,
)


_LISTJOBINFORESPONSE = _descriptor.Descriptor(
  name='ListJobInfoResponse',
  full_name='ai_flow.ListJobInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai_flow.ListJobInfoResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_list', full_name='ai_flow.ListJobInfoResponse.job_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1224,
)

_SCHEDULEWORKFLOWREQUEST_ARGSENTRY.containing_type = _SCHEDULEWORKFLOWREQUEST
_SCHEDULEWORKFLOWREQUEST.fields_by_name['args'].message_type = _SCHEDULEWORKFLOWREQUEST_ARGSENTRY
_WORKFLOWEXECUTIONREQUEST_ARGSENTRY.containing_type = _WORKFLOWEXECUTIONREQUEST
_WORKFLOWEXECUTIONREQUEST.fields_by_name['args'].message_type = _WORKFLOWEXECUTIONREQUEST_ARGSENTRY
_WORKFLOWINFORESPONSE.fields_by_name['result'].message_type = message__pb2._RESULTPROTO
_WORKFLOWINFORESPONSE.fields_by_name['workflow'].message_type = message__pb2._WORKFLOWPROTO
_LISTWORKFLOWINFORESPONSE.fields_by_name['result'].message_type = message__pb2._RESULTPROTO
_LISTWORKFLOWINFORESPONSE.fields_by_name['workflow_list'].message_type = message__pb2._WORKFLOWPROTO
_WORKFLOWEXECUTIONRESPONSE.fields_by_name['result'].message_type = message__pb2._RESULTPROTO
_WORKFLOWEXECUTIONRESPONSE.fields_by_name['workflow_execution'].message_type = message__pb2._WORKFLOWEXECUTIONPROTO
_LISTWORKFLOWEXECUTIONRESPONSE.fields_by_name['result'].message_type = message__pb2._RESULTPROTO
_LISTWORKFLOWEXECUTIONRESPONSE.fields_by_name['workflow_execution_list'].message_type = message__pb2._WORKFLOWEXECUTIONPROTO
_JOBINFORESPONSE.fields_by_name['result'].message_type = message__pb2._RESULTPROTO
_JOBINFORESPONSE.fields_by_name['job'].message_type = message__pb2._JOBPROTO
_LISTJOBINFORESPONSE.fields_by_name['result'].message_type = message__pb2._RESULTPROTO
_LISTJOBINFORESPONSE.fields_by_name['job_list'].message_type = message__pb2._JOBPROTO
DESCRIPTOR.message_types_by_name['ScheduleWorkflowRequest'] = _SCHEDULEWORKFLOWREQUEST
DESCRIPTOR.message_types_by_name['WorkflowExecutionRequest'] = _WORKFLOWEXECUTIONREQUEST
DESCRIPTOR.message_types_by_name['ScheduleJobRequest'] = _SCHEDULEJOBREQUEST
DESCRIPTOR.message_types_by_name['WorkflowInfoResponse'] = _WORKFLOWINFORESPONSE
DESCRIPTOR.message_types_by_name['ListWorkflowInfoResponse'] = _LISTWORKFLOWINFORESPONSE
DESCRIPTOR.message_types_by_name['WorkflowExecutionResponse'] = _WORKFLOWEXECUTIONRESPONSE
DESCRIPTOR.message_types_by_name['ListWorkflowExecutionResponse'] = _LISTWORKFLOWEXECUTIONRESPONSE
DESCRIPTOR.message_types_by_name['JobInfoResponse'] = _JOBINFORESPONSE
DESCRIPTOR.message_types_by_name['ListJobInfoResponse'] = _LISTJOBINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScheduleWorkflowRequest = _reflection.GeneratedProtocolMessageType('ScheduleWorkflowRequest', (_message.Message,), {

  'ArgsEntry' : _reflection.GeneratedProtocolMessageType('ArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEDULEWORKFLOWREQUEST_ARGSENTRY,
    '__module__' : 'scheduling_service_pb2'
    # @@protoc_insertion_point(class_scope:ai_flow.ScheduleWorkflowRequest.ArgsEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEDULEWORKFLOWREQUEST,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.ScheduleWorkflowRequest)
  })
_sym_db.RegisterMessage(ScheduleWorkflowRequest)
_sym_db.RegisterMessage(ScheduleWorkflowRequest.ArgsEntry)

WorkflowExecutionRequest = _reflection.GeneratedProtocolMessageType('WorkflowExecutionRequest', (_message.Message,), {

  'ArgsEntry' : _reflection.GeneratedProtocolMessageType('ArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKFLOWEXECUTIONREQUEST_ARGSENTRY,
    '__module__' : 'scheduling_service_pb2'
    # @@protoc_insertion_point(class_scope:ai_flow.WorkflowExecutionRequest.ArgsEntry)
    })
  ,
  'DESCRIPTOR' : _WORKFLOWEXECUTIONREQUEST,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.WorkflowExecutionRequest)
  })
_sym_db.RegisterMessage(WorkflowExecutionRequest)
_sym_db.RegisterMessage(WorkflowExecutionRequest.ArgsEntry)

ScheduleJobRequest = _reflection.GeneratedProtocolMessageType('ScheduleJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEJOBREQUEST,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.ScheduleJobRequest)
  })
_sym_db.RegisterMessage(ScheduleJobRequest)

WorkflowInfoResponse = _reflection.GeneratedProtocolMessageType('WorkflowInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWINFORESPONSE,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.WorkflowInfoResponse)
  })
_sym_db.RegisterMessage(WorkflowInfoResponse)

ListWorkflowInfoResponse = _reflection.GeneratedProtocolMessageType('ListWorkflowInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKFLOWINFORESPONSE,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.ListWorkflowInfoResponse)
  })
_sym_db.RegisterMessage(ListWorkflowInfoResponse)

WorkflowExecutionResponse = _reflection.GeneratedProtocolMessageType('WorkflowExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWEXECUTIONRESPONSE,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.WorkflowExecutionResponse)
  })
_sym_db.RegisterMessage(WorkflowExecutionResponse)

ListWorkflowExecutionResponse = _reflection.GeneratedProtocolMessageType('ListWorkflowExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKFLOWEXECUTIONRESPONSE,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.ListWorkflowExecutionResponse)
  })
_sym_db.RegisterMessage(ListWorkflowExecutionResponse)

JobInfoResponse = _reflection.GeneratedProtocolMessageType('JobInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFORESPONSE,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.JobInfoResponse)
  })
_sym_db.RegisterMessage(JobInfoResponse)

ListJobInfoResponse = _reflection.GeneratedProtocolMessageType('ListJobInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBINFORESPONSE,
  '__module__' : 'scheduling_service_pb2'
  # @@protoc_insertion_point(class_scope:ai_flow.ListJobInfoResponse)
  })
_sym_db.RegisterMessage(ListJobInfoResponse)


DESCRIPTOR._options = None
_SCHEDULEWORKFLOWREQUEST_ARGSENTRY._options = None
_WORKFLOWEXECUTIONREQUEST_ARGSENTRY._options = None

_SCHEDULINGSERVICE = _descriptor.ServiceDescriptor(
  name='SchedulingService',
  full_name='ai_flow.SchedulingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1227,
  serialized_end=3350,
  methods=[
  _descriptor.MethodDescriptor(
    name='submitWorkflow',
    full_name='ai_flow.SchedulingService.submitWorkflow',
    index=0,
    containing_service=None,
    input_type=_SCHEDULEWORKFLOWREQUEST,
    output_type=_WORKFLOWINFORESPONSE,
    serialized_options=b'\202\323\344\223\002\'\"\"/aiflow/scheduling/workflow/submit:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='deleteWorkflow',
    full_name='ai_flow.SchedulingService.deleteWorkflow',
    index=1,
    containing_service=None,
    input_type=_SCHEDULEWORKFLOWREQUEST,
    output_type=_WORKFLOWINFORESPONSE,
    serialized_options=b'\202\323\344\223\002\'\"\"/aiflow/scheduling/workflow/delete:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='pauseWorkflowScheduling',
    full_name='ai_flow.SchedulingService.pauseWorkflowScheduling',
    index=2,
    containing_service=None,
    input_type=_SCHEDULEWORKFLOWREQUEST,
    output_type=_WORKFLOWINFORESPONSE,
    serialized_options=b'\202\323\344\223\002&\"!/aiflow/scheduling/workflow/pause:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='resumeWorkflowScheduling',
    full_name='ai_flow.SchedulingService.resumeWorkflowScheduling',
    index=3,
    containing_service=None,
    input_type=_SCHEDULEWORKFLOWREQUEST,
    output_type=_WORKFLOWINFORESPONSE,
    serialized_options=b'\202\323\344\223\002\'\"\"/aiflow/scheduling/workflow/resume:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getWorkflow',
    full_name='ai_flow.SchedulingService.getWorkflow',
    index=4,
    containing_service=None,
    input_type=_SCHEDULEWORKFLOWREQUEST,
    output_type=_WORKFLOWINFORESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/aiflow/scheduling/workflow/get',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='listWorkflows',
    full_name='ai_flow.SchedulingService.listWorkflows',
    index=5,
    containing_service=None,
    input_type=_SCHEDULEWORKFLOWREQUEST,
    output_type=_LISTWORKFLOWINFORESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /aiflow/scheduling/workflow/list',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='startNewWorkflowExecution',
    full_name='ai_flow.SchedulingService.startNewWorkflowExecution',
    index=6,
    containing_service=None,
    input_type=_WORKFLOWEXECUTIONREQUEST,
    output_type=_WORKFLOWEXECUTIONRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"//aiflow/scheduling/workflow_execution/start_new:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='killAllWorkflowExecutions',
    full_name='ai_flow.SchedulingService.killAllWorkflowExecutions',
    index=7,
    containing_service=None,
    input_type=_WORKFLOWEXECUTIONREQUEST,
    output_type=_LISTWORKFLOWEXECUTIONRESPONSE,
    serialized_options=b'\202\323\344\223\0023\"./aiflow/scheduling/workflow_execution/kill_all:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='killWorkflowExecution',
    full_name='ai_flow.SchedulingService.killWorkflowExecution',
    index=8,
    containing_service=None,
    input_type=_WORKFLOWEXECUTIONREQUEST,
    output_type=_WORKFLOWEXECUTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002/\"*/aiflow/scheduling/workflow_execution/kill:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getWorkflowExecution',
    full_name='ai_flow.SchedulingService.getWorkflowExecution',
    index=9,
    containing_service=None,
    input_type=_WORKFLOWEXECUTIONREQUEST,
    output_type=_WORKFLOWEXECUTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/aiflow/scheduling/workflow_execution/get',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='listWorkflowExecutions',
    full_name='ai_flow.SchedulingService.listWorkflowExecutions',
    index=10,
    containing_service=None,
    input_type=_WORKFLOWEXECUTIONREQUEST,
    output_type=_LISTWORKFLOWEXECUTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/aiflow/scheduling/workflow_execution/list',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='startJob',
    full_name='ai_flow.SchedulingService.startJob',
    index=11,
    containing_service=None,
    input_type=_SCHEDULEJOBREQUEST,
    output_type=_JOBINFORESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\034/aiflow/scheduling/job/start:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='stopJob',
    full_name='ai_flow.SchedulingService.stopJob',
    index=12,
    containing_service=None,
    input_type=_SCHEDULEJOBREQUEST,
    output_type=_JOBINFORESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\033/aiflow/scheduling/job/stop:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='restartJob',
    full_name='ai_flow.SchedulingService.restartJob',
    index=13,
    containing_service=None,
    input_type=_SCHEDULEJOBREQUEST,
    output_type=_JOBINFORESPONSE,
    serialized_options=b'\202\323\344\223\002#\"\036/aiflow/scheduling/job/restart:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getJob',
    full_name='ai_flow.SchedulingService.getJob',
    index=14,
    containing_service=None,
    input_type=_SCHEDULEJOBREQUEST,
    output_type=_JOBINFORESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/aiflow/scheduling/job/get',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='listJobs',
    full_name='ai_flow.SchedulingService.listJobs',
    index=15,
    containing_service=None,
    input_type=_SCHEDULEJOBREQUEST,
    output_type=_LISTJOBINFORESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/aiflow/scheduling/job/list',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCHEDULINGSERVICE)

DESCRIPTOR.services_by_name['SchedulingService'] = _SCHEDULINGSERVICE

SchedulingService = service_reflection.GeneratedServiceType('SchedulingService', (_service.Service,), dict(
  DESCRIPTOR = _SCHEDULINGSERVICE,
  __module__ = 'scheduling_service_pb2'
  ))

SchedulingService_Stub = service_reflection.GeneratedServiceStubType('SchedulingService_Stub', (SchedulingService,), dict(
  DESCRIPTOR = _SCHEDULINGSERVICE,
  __module__ = 'scheduling_service_pb2'
  ))


# @@protoc_insertion_point(module_scope)



#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
from __future__ import annotations

import json
from typing import Tuple, Dict
from notification_service.base_notification import BaseEvent, DEFAULT_NAMESPACE, ANY_CONDITION
from airflow.executors.scheduling_action import SchedulingAction


class EventKey(object):

    def __init__(self, key, event_type, namespace=DEFAULT_NAMESPACE, sender=ANY_CONDITION) -> None:
        super().__init__()
        self.key = key
        self.event_type = event_type
        self.namespace = namespace
        self.sender = sender


class EventHandler(object):
    """
    EventMetHandler: process event[Event] message and task decide what [TaskAction] to take.
    """
    def handle_event(self, event: BaseEvent, task_state: object) -> Tuple[SchedulingAction, object]:
        """
        :param event: scheduler accepted event.
        :param task_state: user defined state that can help decide the [TaskAction].
        :return: TaskAction to take, the user defined state
        """
        pass

    @staticmethod
    def serialize(handler_to_serialize: EventHandler) -> str:
        """
        Serialize the event handler to json string. All field of the event handler should be JSON serializable.
        If some fields are not JSON serializable, TypeError will raise.
        :param handler_to_serialize: the event handler to serialize.
        :type handler_to_serialize: EventHandler
        :return: json string.
        :rtype: str
        """
        object_dict = dict(handler_to_serialize.__dict__)
        object_dict['__module'] = handler_to_serialize.__class__.__module__
        object_dict['__classname'] = handler_to_serialize.__class__.__name__
        return json.dumps(object_dict)

    @staticmethod
    def deserialize(str_to_deserialize: str) -> EventHandler:
        """
        Deserialize the event handler json string to event handler.
        The json string should be a dictionary that includes both __module__ and __classname__. If either is missing,
        KeyError will raise.
        :param str_to_deserialize: json string to deserialize to event handler.
        :type str_to_deserialize: str
        :return: Deserialized event handler
        :rtype: EventHandler
        """
        import importlib
        object_dict: Dict = json.loads(str_to_deserialize)
        module_name = object_dict.pop('__module')
        classname = object_dict.pop('__classname')
        module = importlib.import_module(module_name)
        clazz = getattr(module, classname)
        handler = clazz(**object_dict)
        for k, v in object_dict.items():
            setattr(handler, k, v)
        return handler




#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#
from ai_flow.common.configuration import AIFlowConfiguration


class ProjectConfig(AIFlowConfiguration):
    """
    Configuration information of ai flow project.
    """
    def get_server_ip(self):
        """
        return: The ai_flow.endpoint.server.server.AIFlowServer ip.
        """
        return self["server_ip"]

    def set_server_ip(self, value):
        self["server_ip"] = value

    def get_server_port(self):
        """
        return: The ai_flow.endpoint.server.server.AIFlowServer port.
        """
        return self["server_port"]

    def set_server_port(self, value):
        self["server_port"] = value

    def get_server_uri(self):
        """
        return: The ai_flow.endpoint.server.server.AIFlowServer uri(ip:port).
        """
        return "{}:{}".format(self["server_ip"], self["server_port"])

    def get_project_name(self):
        """
        return: The name of an ai flow project.
        """
        return self["project_name"]

    def set_project_name(self, value):
        self["project_name"] = value

    def get_project_uuid(self):
        """
        return: The unique id of the ai flow project, it is generated by ai flow meta service.
        """
        if "project_uuid" in self:
            return self["project_uuid"]
        else:
            return None

    def set_project_uuid(self, value):
        self["project_uuid"] = value

    def get_notification_service_uri(self):
        """
        return: The notification service(notification_service.master.NotificationMaster) uri.
        """
        if "notification_uri" in self:
            return self["notification_uri"]
        else:
            return self.get_server_uri()

    def set_notification_service_uri(self, uri):
        self["notification_uri"] = uri

    def get_enable_ha(self):
        """
        Use ai_flow.endpoint.server.server.AIFlowServer ha mode or not.
        If use AIFlowServer ha return True else return False
        """
        if "enable_ha" in self:
            raw = self["enable_ha"]
            assert str(raw).strip().lower() in {"true", "false"}
            return bool(str(raw).strip().lower())
        else:
            return False

    def set_enable_ha(self, enable_ha):
        assert str(enable_ha).strip().lower() in {"true", "false"}
        self["enable_ha"] = enable_ha

    def _get_time_interval_ms(self, key, default):
        if key in self:
            raw = self[key]
            assert int(str(raw).strip()) >= 0
            return int(str(raw).strip())
        else:
            return default

    def _set_time_interval_ms(self, key, value):
        assert int(str(value).strip()) >= 0
        self[key] = value

    def get_list_member_interval_ms(self):
        """
        If in ha mode, the ai flow client (ai_flow.client.ai_flow_client.AIFlowClient)
        will periodic find ai flow server(ai_flow.endpoint.server.server.AIFlowServer).
        This parameter represents the time interval(millisecond) between two searches for the server.
        """
        return self._get_time_interval_ms("list_member_interval_ms", 5000)

    def set_list_member_interval_ms(self, list_member_interval_ms):
        self._set_time_interval_ms("list_member_interval_ms", list_member_interval_ms)

    def get_retry_interval_ms(self):
        """
        In ha mode, if the ai flow client (ai_flow.client.ai_flow_client.AIFlowClient) lose the
        ai flow server(ai_flow.endpoint.server.server.AIFlowServer), it will try to connect the server.
        This parameter represents the time interval(millisecond) between two trying to connect the server.
        """
        return self._get_time_interval_ms("retry_interval_ms", 1000)

    def set_retry_interval_ms(self, retry_interval_ms):
        self._set_time_interval_ms("retry_interval_ms", retry_interval_ms)

    def get_retry_timeout_ms(self):
        """
        In ha mode, if the ai flow client (ai_flow.client.ai_flow_client.AIFlowClient) lose the
        ai flow server(ai_flow.endpoint.server.server.AIFlowServer), it will try to connect the server.
        This parameter indicates the maximum time the client attempts to connect to the server.
        If this time is exceeded, the client will throw an error.
        """
        return self._get_time_interval_ms("retry_timeout_ms", 10000)

    def set_retry_timeout_ms(self, retry_timeout_ms):
        self._set_time_interval_ms("retry_timeout_ms", retry_timeout_ms)




#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

"""Make TaskInstance.pool not nullable

Revision ID: 6e96a59344a4
Revises: 939bb1e647c8
Create Date: 2019-06-13 21:51:32.878437

"""

import dill
import sqlalchemy as sa
from alembic import op
from sqlalchemy import Column, Float, Integer, PickleType, String
from sqlalchemy.ext.declarative import declarative_base

from airflow.models.base import COLLATION_ARGS
from airflow.utils.session import create_session
from airflow.utils.sqlalchemy import UtcDateTime

# revision identifiers, used by Alembic.
revision = '6e96a59344a4'
down_revision = '939bb1e647c8'
branch_labels = None
depends_on = None

Base = declarative_base()
ID_LEN = 250


class TaskInstance(Base):  # type: ignore
    """
    Task instances store the state of a task instance. This table is the
    authority and single source of truth around what tasks have run and the
    state they are in.

    The SqlAlchemy model doesn't have a SqlAlchemy foreign key to the task or
    dag model deliberately to have more control over transactions.

    Database transactions on this table should insure double triggers and
    any confusion around what task instances are or aren't ready to run
    even while multiple schedulers may be firing task instances.
    """

    __tablename__ = "task_instance"

    task_id = Column(String(ID_LEN, **COLLATION_ARGS), primary_key=True)
    dag_id = Column(String(ID_LEN, **COLLATION_ARGS), primary_key=True)
    execution_date = Column(UtcDateTime, primary_key=True)
    start_date = Column(UtcDateTime)
    end_date = Column(UtcDateTime)
    duration = Column(Float)
    state = Column(String(20))
    _try_number = Column('try_number', Integer, default=0)
    max_tries = Column(Integer)
    hostname = Column(String(1000))
    unixname = Column(String(1000))
    job_id = Column(Integer)
    pool = Column(String(50), nullable=False)
    queue = Column(String(256))
    priority_weight = Column(Integer)
    operator = Column(String(1000))
    queued_dttm = Column(UtcDateTime)
    pid = Column(Integer)
    executor_config = Column(PickleType(pickler=dill))


def upgrade():
    """Make TaskInstance.pool field not nullable."""
    with create_session() as session:
        session.query(TaskInstance).filter(TaskInstance.pool.is_(None)).update(
            {TaskInstance.pool: 'default_pool'}, synchronize_session=False
        )  # Avoid select updated rows
        session.commit()

    conn = op.get_bind()
    if conn.dialect.name == "mssql":
        op.drop_index('ti_pool', table_name='task_instance')

    # use batch_alter_table to support SQLite workaround
    with op.batch_alter_table('task_instance') as batch_op:
        batch_op.alter_column(
            column_name='pool',
            type_=sa.String(50),
            nullable=False,
        )

    if conn.dialect.name == "mssql":
        op.create_index('ti_pool', 'task_instance', ['pool', 'state', 'priority_weight'])


def downgrade():
    """Make TaskInstance.pool field nullable."""
    conn = op.get_bind()
    if conn.dialect.name == "mssql":
        op.drop_index('ti_pool', table_name='task_instance')

    # use batch_alter_table to support SQLite workaround
    with op.batch_alter_table('task_instance') as batch_op:
        batch_op.alter_column(
            column_name='pool',
            type_=sa.String(50),
            nullable=True,
        )

    if conn.dialect.name == "mssql":
        op.create_index('ti_pool', 'task_instance', ['pool', 'state', 'priority_weight'])

    with create_session() as session:
        session.query(TaskInstance).filter(TaskInstance.pool == 'default_pool').update(
            {TaskInstance.pool: None}, synchronize_session=False
        )  # Avoid select updated rows
        session.commit()
